# -*- coding: utf-8 -*-

"""
    pepipost.models.personalizations

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import pepipost.models.attachments

class Personalizations(object):

    """Implementation of the 'Personalizations' model.

    This consits of personlized attachments with recipient,recipient_cc,etc.

    Attributes:
        recipient (string): Emails to be passed in Apicall
        x_apiheader_cc (string): TODO: type description here.
        x_apiheader (string): TODO: type description here.
        attributes (object): TODO: type description here.
        attachments (list of Attachments): TODO: type description here.
        recipient_cc (list of string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "recipient":'recipient',
        "x_apiheader_cc":'x-apiheader_cc',
        "x_apiheader":'x-apiheader',
        "attributes":'attributes',
        "attachments":'attachments',
        "recipient_cc":'recipient_cc'
    }

    def __init__(self,
                 recipient=None,
                 x_apiheader_cc=None,
                 x_apiheader=None,
                 attributes=None,
                 attachments=None,
                 recipient_cc=None):
        """Constructor for the Personalizations class"""

        # Initialize members of the class
        self.recipient = recipient
        self.x_apiheader_cc = x_apiheader_cc
        self.x_apiheader = x_apiheader
        self.attributes = attributes
        self.attachments = attachments
        self.recipient_cc = recipient_cc


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        recipient = dictionary.get('recipient')
        x_apiheader_cc = dictionary.get('x-apiheader_cc')
        x_apiheader = dictionary.get('x-apiheader')
        attributes = dictionary.get('attributes')
        attachments = None
        if dictionary.get('attachments') != None:
            attachments = list()
            for structure in dictionary.get('attachments'):
                attachments.append(pepipost.models.attachments.Attachments.from_dictionary(structure))
        recipient_cc = dictionary.get('recipient_cc')

        # Return an object of this model
        return cls(recipient,
                   x_apiheader_cc,
                   x_apiheader,
                   attributes,
                   attachments,
                   recipient_cc)





# -*- coding: utf-8 -*-

"""
    pepipost.models.email_body

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import pepipost.models.personalizations
import pepipost.models.mfrom
import pepipost.models.email_body_attachments
import pepipost.models.settings

class EmailBody(object):

    """Implementation of the 'emailBody' model.

    Mail Body which will be passed as json in apicall.

    Attributes:
        personalizations (list of Personalizations): TODO: type description
            here.
        tags (string): TODO: type description here.
        mfrom (From): TODO: type description here.
        subject (string): TODO: type description here.
        content (string): TODO: type description here.
        attachments (list of EmailBodyAttachments): TODO: type description
            here.
        settings (Settings): TODO: type description here.
        reply_to_id (string): TODO: type description here.
        template_id (int): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "personalizations":'personalizations',
        "tags":'tags',
        "mfrom":'from',
        "subject":'subject',
        "content":'content',
        "attachments":'attachments',
        "settings":'settings',
        "reply_to_id":'replyToId',
        "template_id":'templateId'
    }

    def __init__(self,
                 personalizations=None,
                 tags=None,
                 mfrom=None,
                 subject=None,
                 content=None,
                 attachments=None,
                 settings=None,
                 reply_to_id=None,
                 template_id=None):
        """Constructor for the EmailBody class"""

        # Initialize members of the class
        self.personalizations = personalizations
        self.tags = tags
        self.mfrom = mfrom
        self.subject = subject
        self.content = content
        self.attachments = attachments
        self.settings = settings
        self.reply_to_id = reply_to_id
        self.template_id = template_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        personalizations = None
        if dictionary.get('personalizations') != None:
            personalizations = list()
            for structure in dictionary.get('personalizations'):
                personalizations.append(pepipost.models.personalizations.Personalizations.from_dictionary(structure))
        tags = dictionary.get('tags')
        mfrom = pepipost.models.mfrom.From.from_dictionary(dictionary.get('from')) if dictionary.get('from') else None
        subject = dictionary.get('subject')
        content = dictionary.get('content')
        attachments = None
        if dictionary.get('attachments') != None:
            attachments = list()
            for structure in dictionary.get('attachments'):
                attachments.append(pepipost.models.email_body_attachments.EmailBodyAttachments.from_dictionary(structure))
        settings = pepipost.models.settings.Settings.from_dictionary(dictionary.get('settings')) if dictionary.get('settings') else None
        reply_to_id = dictionary.get('replyToId')
        template_id = dictionary.get('templateId')

        # Return an object of this model
        return cls(personalizations,
                   tags,
                   mfrom,
                   subject,
                   content,
                   attachments,
                   settings,
                   reply_to_id,
                   template_id)





# -*- coding: utf-8 -*-

"""
    pepipost.models.send_email_error

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class SendEmailError(object):

    """Implementation of the 'sendEmailError' model.

    TODO: type model description here.

    Attributes:
        error_message (string): TODO: type description here.
        error_code (int): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "error_message":'error_message',
        "error_code":'error_code'
    }

    def __init__(self,
                 error_message=None,
                 error_code=None):
        """Constructor for the SendEmailError class"""

        # Initialize members of the class
        self.error_message = error_message
        self.error_code = error_code


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        error_message = dictionary.get('error_message')
        error_code = dictionary.get('error_code')

        # Return an object of this model
        return cls(error_message,
                   error_code)





# -*- coding: utf-8 -*-

"""
   pepipost.configuration

   This file was automatically generated by APIMATIC v2.0
   ( https://apimatic.io )
"""
from .api_helper import APIHelper


class Configuration(object):

    """A class used for configuring the SDK by a user.

    This class need not be instantiated and all properties and methods
    are accessible without instance creation.

    """

    # Set the array parameter serialization method
    # (allowed: indexed, unindexed, plain, csv, tsv, psv)
    array_serialization = "indexed"

    # The base Uri for API calls
    base_uri = 'http://api.pepipost.com'




# -*- coding: utf-8 -*-

"""
    pepipost.models.settings

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class Settings(object):

    """Implementation of the 'Settings' model.

    TODO: type model description here.

    Attributes:
        footer (int): TODO: type description here.
        clicktrack (int): TODO: type description here.
        opentrack (int): TODO: type description here.
        unsubscribe (int): TODO: type description here.
        bcc (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "footer":'footer',
        "clicktrack":'clicktrack',
        "opentrack":'opentrack',
        "unsubscribe":'unsubscribe',
        "bcc":'bcc'
    }

    def __init__(self,
                 footer=None,
                 clicktrack=None,
                 opentrack=None,
                 unsubscribe=None,
                 bcc=None):
        """Constructor for the Settings class"""

        # Initialize members of the class
        self.footer = footer
        self.clicktrack = clicktrack
        self.opentrack = opentrack
        self.unsubscribe = unsubscribe
        self.bcc = bcc


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        footer = dictionary.get('footer')
        clicktrack = dictionary.get('clicktrack')
        opentrack = dictionary.get('opentrack')
        unsubscribe = dictionary.get('unsubscribe')
        bcc = dictionary.get('bcc')

        # Return an object of this model
        return cls(footer,
                   clicktrack,
                   opentrack,
                   unsubscribe,
                   bcc)





# -*- coding: utf-8 -*-

"""
    pepipost.controllers.email_controller

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from .base_controller import BaseController
from ..api_helper import APIHelper
from ..configuration import Configuration
from ..models.send_email_response import SendEmailResponse
from ..exceptions.api_exception import APIException

class EmailController(BaseController):

    """A Controller to access Endpoints in the pepipost API."""


    def create_send_email(self,
                          api_key=None,
                          body=None):
        """Does a POST request to /v2/sendEmail.

        This Endpoint sends emails with the credentials passed.

        Args:
            api_key (string, optional): Generated header parameter. Example
                value ='5ce7096ed4bf2b39dfa932ff5fa84ed9ed8'
            body (EmailBody, optional): The body passed will be json format.

        Returns:
            SendEmailResponse: Response from the API. 

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _query_builder = Configuration.base_uri
        _query_builder += '/v2/sendEmail'
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8',
            'api_key': api_key
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _context = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _context.response.status_code == 405:
            raise APIException('Method not allowed', _context)
        self.validate_response(_context)

        # Return appropriate type
        return APIHelper.json_deserialize(_context.response.raw_body, SendEmailResponse.from_dictionary)



# -*- coding: utf-8 -*-

"""
    pepipost.pepipost_client

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""
from .decorators import lazy_property
from .configuration import Configuration
from .controllers.email_controller import EmailController

class PepipostClient(object):

    config = Configuration

    @lazy_property
    def email(self):
        return EmailController()






# -*- coding: utf-8 -*-

"""
    pepipost.models.mfrom

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""


class From(object):

    """Implementation of the 'From' model.

    TODO: type model description here.

    Attributes:
        from_email (string): TODO: type description here.
        from_name (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "from_email":'fromEmail',
        "from_name":'fromName'
    }

    def __init__(self,
                 from_email=None,
                 from_name=None):
        """Constructor for the From class"""

        # Initialize members of the class
        self.from_email = from_email
        self.from_name = from_name


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        from_email = dictionary.get('fromEmail')
        from_name = dictionary.get('fromName')

        # Return an object of this model
        return cls(from_email,
                   from_name)





__all__ = [
    'attribute',
    'mfrom',
    'email_body_attachments',
    'attachments',
    'personalizations',
    'email_body',
    'settings',
    'send_email_error',
    'send_email_response',
]


# -*- coding: utf-8 -*-

"""
    pepipost.models.send_email_response

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io )
"""
import pepipost.models.send_email_error

class SendEmailResponse(object):

    """Implementation of the 'sendEmailResponse' model.

    Response of the email

    Attributes:
        data (object): TODO: type description here.
        message (string): TODO: type description here.
        error_info (SendEmailError): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "data":'data',
        "message":'message',
        "error_info":'error_info'
    }

    def __init__(self,
                 data=None,
                 message=None,
                 error_info=None):
        """Constructor for the SendEmailResponse class"""

        # Initialize members of the class
        self.data = data
        self.message = message
        self.error_info = error_info


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        data = dictionary.get('data')
        message = dictionary.get('message')
        error_info = pepipost.models.send_email_error.SendEmailError.from_dictionary(dictionary.get('error_info')) if dictionary.get('error_info') else None

        # Return an object of this model
        return cls(data,
                   message,
                   error_info)





from setuptools import setup, find_packages

# Try to convert markdown README to rst format for PyPI.
try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except(IOError, ImportError):
    long_description = open('README.md').read()

setup(
    name='pepipost',
    version='2.5.0',
    description='Official Python Library by Pepipost for sending email using Web API v2',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Vikram Sahu - DX Team, Pepipost & APIMatic',
    maintainer='vikramsahu',
    author_email='dx@pepipost.com',
    url='https://pepipost.com/',
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        ],
    install_requires=[
        'requests>=2.9.1, <3.0',
        'jsonpickle>=0.7.1, <1.0',
        'cachecontrol>=0.11.7, <1.0',
        'python-dateutil>=2.5.3, <3.0'
        ]
)
